==> hprose-java-1.6.0-sources.jar: hprose/io/unserialize/DoubleArrayUnserializer.java <==
/**********************************************************\
|                                                          |
|                          hprose                          |
|                                                          |
| Official WebSite: http://www.hprose.com/                 |
|                   http://www.hprose.org/                 |
|                                                          |
\**********************************************************/
/**********************************************************\
 *                                                        *
 * DoubleArrayUnserializer.java                           *
 *                                                        *
 * double array unserializer class for Java.              *
 *                                                        *
 * LastModified: Apr 17, 2016                             *
 * Author: Ma Bingyao <andot@hprose.com>                  *
 *                                                        *
\**********************************************************/

package hprose.io.unserialize;

import static hprose.io.HproseTags.TagList;
import static hprose.io.HproseTags.TagNull;
import static hprose.io.HproseTags.TagOpenbrace;
import static hprose.io.HproseTags.TagRef;
import java.io.IOException;
import java.io.InputStream;
import java.lang.reflect.Array;
import java.lang.reflect.Type;
import java.nio.ByteBuffer;

final class DoubleArrayUnserializer implements Unserializer {

    public final static DoubleArrayUnserializer instance = new DoubleArrayUnserializer();

    final static double[] read(Reader reader, ByteBuffer buffer) throws IOException {
        int tag = buffer.get();
        switch (tag) {
            case TagNull: return null;
            case TagList: {
                int count = ValueReader.readInt(buffer, TagOpenbrace);
                double[] a = new double[count];
                reader.refer.set(a);
                for (int i = 0; i < count; ++i) {
                    a[i] = DoubleUnserializer.read(reader, buffer);
                }
                buffer.get();
                return a;
            }
            case TagRef: return (double[])reader.readRef(buffer);
            default: throw ValueReader.castError(reader.tagToString(tag), Array.class);
        }
    }

    final static double[] read(Reader reader, InputStream stream) throws IOException {
        int tag = stream.read();
        switch (tag) {
            case TagNull: return null;
            case TagList: {
                int count = ValueReader.readInt(stream, TagOpenbrace);
                double[] a = new double[count];
                reader.refer.set(a);
                for (int i = 0; i < count; ++i) {
                    a[i] = DoubleUnserializer.read(reader, stream);
                }
                stream.read();
                return a;
            }
            case TagRef: return (double[])reader.readRef(stream);
            default: throw ValueReader.castError(reader.tagToString(tag), Array.class);
        }
    }

    public final Object read(Reader reader, ByteBuffer buffer, Class<?> cls, Type type) throws IOException {
        return read(reader, buffer);
    }

    public final Object read(Reader reader, InputStream stream, Class<?> cls, Type type) throws IOException {
        return read(reader, stream);
    }

}

==> hprose-java-2.0.38-sources.jar: hprose/io/unserialize/DoubleArrayUnserializer.java <==
/**********************************************************\
|                                                          |
|                          hprose                          |
|                                                          |
| Official WebSite: http://www.hprose.com/                 |
|                   http://www.hprose.org/                 |
|                                                          |
\**********************************************************/
/**********************************************************\
 *                                                        *
 * DoubleArrayUnserializer.java                           *
 *                                                        *
 * double array unserializer class for Java.              *
 *                                                        *
 * LastModified: Aug 3, 2016                              *
 * Author: Ma Bingyao <andot@hprose.com>                  *
 *                                                        *
\**********************************************************/

package hprose.io.unserialize;

import static hprose.io.HproseTags.TagEmpty;
import static hprose.io.HproseTags.TagList;
import java.io.IOException;
import java.lang.reflect.Type;

public final class DoubleArrayUnserializer extends BaseUnserializer<double[]> {

    public final static DoubleArrayUnserializer instance = new DoubleArrayUnserializer();

    @Override
    public double[] unserialize(Reader reader, int tag, Type type) throws IOException {
        if (tag == TagList) return ReferenceReader.readDoubleArray(reader);
        if (tag == TagEmpty) return new double[0];
        return super.unserialize(reader, tag, type);
    }

    public double[] read(Reader reader) throws IOException {
        return read(reader, double[].class);
    }
}
